@@ -104,7 +104,7 @@ function aggregate_form_save() {
 		return null;
 	}
 
-	cacti_log('AGGREGATE GRAPH TEMPLATE Saved ID: ' . $save1['id'] . ' Name: ' . $save1['name'], FALSE, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
+	cacti_log('AGGREGATE GRAPH TEMPLATE Saved ID: ' . $save1['id'] . ' Name: ' . $save1['name'], false, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
 	/* do a quick comparison to see if anything changed */
 	if ($is_new == false) {
@@ -136,7 +136,7 @@ function aggregate_form_save() {
 			array($save1['gprint_prefix'], $save1['graph_type'],
 				$save1['total'], $save1['total_prefix'],  $save1['order_type'], $id));
 
-		cacti_log('AGGREGATE GRAPH TEMPLATE Saved ID: ' . $id, FALSE, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
+		cacti_log('AGGREGATE GRAPH TEMPLATE Saved ID: ' . $id, false, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 	} else {
 		$id = $save1['id'];
 	}
@@ -309,11 +309,11 @@ function aggregate_form_actions() {
 					</td>
 				</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Delete Color Template(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Color Template(s)') . "'>";
 		}
 	} else {
 		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one Aggregate Graph Template.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}
 
 	print "<tr>
@@ -538,7 +538,7 @@ function aggregate_template() {
 						' . __('Search') . '
 					</td>
 					<td>
-						<input type="text" id="filter" size="25" value="' . get_request_var("filter") . '">
+						<input type="text" id="filter" size="25" value="' . html_escape_request_var('filter') . '">
 					</td>
 					<td>
 						' . __('Templates') . '
@@ -565,21 +565,20 @@ function aggregate_template() {
 	$filter_html .= '</select>
 					</td>
 					<td>
-						<input type="checkbox" id="has_graphs" ' . (get_request_var('has_graphs') == 'true' ? 'checked':'') . ' onChange="applyFilter()">
+						<span>
+							<input type="checkbox" id="has_graphs" ' . (get_request_var('has_graphs') == 'true' ? 'checked':'') . ' onChange="applyFilter()">
+							<label for="has_graphs">' . __('Has Graphs') . '</label>
+						</span>
 					</td>
 					<td>
-						<label for="has_graphs">' . __('Has Graphs') . '</label>
-					</td>
-					<td>
-						<input type="button" value="' . __('Go') . '" id="refresh">
-					</td>
-					<td>
-						<input type="button" value="' . __('Clear') . '" id="clear">
+						<span>
+							<input type="button" value="' . __esc('Go') . '" id="refresh">
+							<input type="button" value="' . __esc('Clear') . '" id="clear">
+						</span>
 					</td>
 				</tr>
 			</table>
 		</td>
-		<td><input type="hidden" id="page" value="' . get_request_var('page') . '"></td>
 	</tr>';
 
 	print $filter_html;
@@ -683,9 +682,8 @@ function aggregate_template() {
 	function applyFilter() {
 		strURL  = 'aggregate_templates.php';
 		strURL += '?rows=' + $('#rows').val();
-		strURL += '&page=' + $('#page').val();
 		strURL += '&has_graphs=' + $('#has_graphs').is(':checked');
-		strURL += '&filter=' + escape($('#filter').val());
+		strURL += '&filter=' + $('#filter').val();
 		strURL += '&header=false';
 		loadPageNoHeader(strURL);
 	}
