@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2012 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -24,137 +24,184 @@
 */
 
 /* do NOT run this script through a web browser */
-if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die("<br><strong>This script is only meant to run at the command line.</strong>");
+if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
+	die('<br><strong>This script is only meant to run at the command line.</strong>');
 }
 
 /* We are not talking to the browser */
 $no_http_headers = true;
 
-include(dirname(__FILE__)."/../include/global.php");
-include_once($config["base_path"]."/lib/api_automation_tools.php");
-include_once($config["base_path"]."/lib/utility.php");
-include_once($config["base_path"]."/lib/api_data_source.php");
-include_once($config["base_path"]."/lib/api_graph.php");
-include_once($config["base_path"]."/lib/snmp.php");
-include_once($config["base_path"]."/lib/data_query.php");
-include_once($config["base_path"]."/lib/api_device.php");
+include(dirname(__FILE__).'/../include/global.php');
+include_once($config['base_path'].'/lib/api_automation_tools.php');
+include_once($config['base_path'].'/lib/utility.php');
+include_once($config['base_path'].'/lib/api_data_source.php');
+include_once($config['base_path'].'/lib/api_graph.php');
+include_once($config['base_path'].'/lib/snmp.php');
+include_once($config['base_path'].'/lib/data_query.php');
+include_once($config['base_path'].'/lib/api_device.php');
 
 /* process calling arguments */
-$parms = $_SERVER["argv"];
+$parms = $_SERVER['argv'];
 array_shift($parms);
 
 if (sizeof($parms)) {
 	/* setup defaults */
-	$description   = "";
-	$ip            = "";
+	$description   = '';
+	$ip            = '';
+	$poller_id     = $config['poller_id'];
+	$site_id       = 0;
 	$template_id   = 0;
-	$community     = read_config_option("snmp_community");
-	$snmp_ver      = read_config_option("snmp_ver");
+	$community     = read_config_option('snmp_community');
+	$snmp_ver      = read_config_option('snmp_ver');
 	$disable       = 0;
 
-	$notes         = "";
+	$notes         = '';
+	$external_id   = '';
 
-	$snmp_username        = read_config_option("snmp_username");
-	$snmp_password        = read_config_option("snmp_password");
-	$snmp_auth_protocol   = read_config_option("snmp_auth_protocol");
-	$snmp_priv_passphrase = read_config_option("snmp_priv_passphrase");
-	$snmp_priv_protocol   = read_config_option("snmp_priv_protocol");
-	$snmp_context         = "";
-	$snmp_port            = read_config_option("snmp_port");
-	$snmp_timeout         = read_config_option("snmp_timeout");
+	$snmp_username        = read_config_option('snmp_username');
+	$snmp_password        = read_config_option('snmp_password');
+	$snmp_auth_protocol   = read_config_option('snmp_auth_protocol');
+	$snmp_priv_passphrase = read_config_option('snmp_priv_passphrase');
+	$snmp_priv_protocol   = read_config_option('snmp_priv_protocol');
+	$snmp_context         = '';
+	$snmp_engine_id       = '';
+	$snmp_port            = read_config_option('snmp_port');
+	$snmp_timeout         = read_config_option('snmp_timeout');
 
 	$avail          = 1;
-	$ping_method    = read_config_option("ping_method");
-	$ping_port      = read_config_option("ping_port");
-	$ping_timeout   = read_config_option("ping_timeout");
-	$ping_retries   = read_config_option("ping_retries");
-	$max_oids       = read_config_option("max_get_size");
-	$device_threads = 1;
+	$ping_method    = read_config_option('ping_method');
+	$ping_port      = read_config_option('ping_port');
+	$ping_timeout   = read_config_option('ping_timeout');
+	$ping_retries   = read_config_option('ping_retries');
+	$max_oids       = read_config_option('max_get_size');
+	$proxy          = false;
+	$device_threads = read_config_option('device_threads');;
 
-	$displayHostTemplates = FALSE;
-	$displayCommunities   = FALSE;
-	$quietMode            = FALSE;
+	$displayHostTemplates = false;
+	$displayCommunities   = false;
+	$quietMode            = false;
 
 	foreach($parms as $parameter) {
-		@list($arg, $value) = @explode("=", $parameter);
+		if (strpos($parameter, '=')) {
+			list($arg, $value) = explode('=', $parameter);
+		} else {
+			$arg = $parameter;
+			$value = '';
+		}
 
 		switch ($arg) {
-		case "-d":
-			$debug = TRUE;
+		case '-d':
+			$debug = true;
 
 			break;
-		case "--description":
+		case '--description':
 			$description = trim($value);
 
 			break;
-		case "--ip":
+		case '--ip':
 			$ip = trim($value);
 
 			break;
-		case "--template":
+		case '--template':
 			$template_id = $value;
 
 			break;
-		case "--community":
+		case '--community':
 			$community = trim($value);
 
 			break;
-		case "--version":
-			$snmp_ver = trim($value);
+		case '--version':
+			if (sizeof($parms) == 1) {
+				display_version();
+				exit;
+			} else {
+				$snmp_ver = trim($value);
+			}
 
 			break;
-		case "--notes":
+		case '--notes':
 			$notes = trim($value);
 
 			break;
-		case "--disable":
+		case '--site':
+			$site_id = trim($value);
+
+			break;
+		case '--poller':
+			$poller_id = trim($value);
+
+			break;
+		case '--disable':
 			$disable  = $value;
 
 			break;
-		case "--username":
+		case '--external-id':
+			$external_id  = $value;
+
+			break;
+		case '--username':
 			$snmp_username = trim($value);
 
 			break;
-		case "--password":
+		case '--password':
 			$snmp_password = trim($value);
 
 			break;
-		case "--authproto":
+		case '--authproto':
 			$snmp_auth_protocol = trim($value);
 
 			break;
-		case "--privproto":
+		case '--privproto':
 			$snmp_priv_protocol = trim($value);
 
 			break;
-		case "--privpass":
+		case '--privpass':
 			$snmp_priv_passphrase = trim($value);
 
 			break;
-		case "--port":
-			$snmp_port     = $value;
+		case '--context':
+			$snmp_context = trim($value);
 
 			break;
-		case "--timeout":
-			$snmp_timeout  = $value;
+		case '--engineid':
+			$snmp_engine_id = trim($value);
 
 			break;
-		case "--avail":
+		case '--port':
+			$snmp_port = $value;
+
+			break;
+		case '--proxy':
+			$proxy = true;
+
+			break;
+		case '--timeout':
+			$snmp_timeout = $value;
+
+			break;
+		case '--ping_timeout':
+			$ping_timeout = $value;
+
+			break;
+		case '--threads':
+			$device_threads = $value;
+
+			break;
+		case '--avail':
 			switch($value) {
-			case "none":
-				$avail = '0'; /* tried to use AVAIL_NONE, but then ereg failes on validation, sigh */
+			case 'none':
+				$avail = '0'; /* tried to use AVAIL_NONE, but then preg_match failes on validation, sigh */
 
 				break;
-			case "ping":
+			case 'ping':
 				$avail = AVAIL_PING;
 
 				break;
-			case "snmp":
+			case 'snmp':
 				$avail = AVAIL_SNMP;
 
 				break;
-			case "pingsnmp":
+			case 'pingsnmp':
 				$avail = AVAIL_SNMP_AND_PING;
 
 				break;
@@ -165,17 +212,17 @@ if (sizeof($parms)) {
 			}
 
 			break;
-		case "--ping_method":
+		case '--ping_method':
 			switch(strtolower($value)) {
-			case "icmp":
+			case 'icmp':
 				$ping_method = PING_ICMP;
 
 				break;
-			case "tcp":
+			case 'tcp':
 				$ping_method = PING_TCP;
 
 				break;
-			case "udp":
+			case 'udp':
 				$ping_method = PING_UDP;
 
 				break;
@@ -186,52 +233,56 @@ if (sizeof($parms)) {
 			}
 
 			break;
-		case "--ping_port":
+		case '--ping_port':
 			if (is_numeric($value) && ($value > 0)) {
 				$ping_port = $value;
-			}else{
+			} else {
 				echo "ERROR: Invalid Ping Port: ($value)\n\n";
 				display_help();
 				exit(1);
 			}
 
 			break;
-		case "--ping_retries":
+		case '--ping_retries':
 			if (is_numeric($value) && ($value > 0)) {
 				$ping_retries = $value;
-			}else{
+			} else {
 				echo "ERROR: Invalid Ping Retries: ($value)\n\n";
 				display_help();
 				exit(1);
 			}
 
 			break;
-		case "--max_oids":
+		case '--max_oids':
 			if (is_numeric($value) && ($value > 0)) {
 				$max_oids = $value;
-			}else{
+			} else {
 				echo "ERROR: Invalid Max OIDS: ($value)\n\n";
 				display_help();
 				exit(1);
 			}
 
 			break;
-		case "--version":
-		case "-V":
-		case "-H":
-		case "--help":
+		case '--version':
+		case '-V':
+		case '-v':
+			display_version();
+			exit;
+		case '--help':
+		case '-H':
+		case '-h':
 			display_help();
-			exit(0);
-		case "--list-communities":
-			$displayCommunities = TRUE;
+			exit;
+		case '--list-communities':
+			$displayCommunities = true;
 
 			break;
-		case "--list-host-templates":
-			$displayHostTemplates = TRUE;
+		case '--list-host-templates':
+			$displayHostTemplates = true;
 
 			break;
-		case "--quiet":
-			$quietMode = TRUE;
+		case '--quiet':
+			$quietMode = true;
 
 			break;
 		default:
@@ -264,7 +315,7 @@ if (sizeof($parms)) {
 
 	/* process host description */
 	if (isset($hosts[$description])) {
-		db_execute("update host set hostname='$ip' where id=" . $hosts[$description]);
+		db_execute("UPDATE host SET hostname='$ip' WHERE id=" . $hosts[$description]);
 		echo "This host already exists in the database ($description) device-id: (" . $hosts[$description] . ")\n";
 		exit(1);
 	}
@@ -274,15 +325,66 @@ if (sizeof($parms)) {
 		exit(1);
 	}
 
-	/* process ip */
-	if (isset($addresses[$ip])) {
-		db_execute("update host set description = '$description' where id = " . $addresses[$ip]);
-		echo "ERROR: This IP already exists in the database ($ip) device-id: (" . $addresses[$ip] . ")\n";
+	if ($ip == "") {
+		echo "ERROR: You must supply an IP address for all hosts!\n";
 		exit(1);
 	}
 
-	if ($ip == "") {
-		echo "ERROR: You must supply an IP address for all hosts!\n";
+	/* process ip */
+	if (isset($addresses[$ip])) {
+		$id = $addresses[$ip];
+		$phost = db_fetch_row_prepared('SELECT * FROM host WHERE id = ?', array($id));
+		$fail = false;
+
+		if ($phost['snmp_version'] < '3' && $snmp_ver < '3') {
+			if ($phost['snmp_community'] != $community) {
+				if ($proxy) {
+					// assuming an snmp-proxy
+				} else {
+					echo "ERROR: This IP ($id) already exists in the database and --proxy was not specified.\n";
+					exit(1);
+				}
+			} else {
+				$fail = true;
+			}
+		} elseif ($phost['snmp_version'] != $snmp_ver) {
+			// assumeing a proxy
+		} elseif ($phost['snmp_version'] == '3' && $snmp_ver == '3') {
+			$changed = 0;
+			$changed += ($phost['snmp_usernanem'] != $username ? 1:0);
+			$changed += ($phost['snmp_context'] != $snmp_context ? 1:0);
+			$changed += ($phost['snmp_engine_id'] != $snmp_engine_id ? 1:0);
+			$changed += ($phost['snmp_auth_protocol'] != $snmp_auth_protocol ? 1:0);
+			$changed += ($phost['snmp_priv_protocol'] != $snmp_priv_protocol ? 1:0);
+
+			if ($changed > 0) {
+				if ($proxy) {
+					// assuming a proxy
+				} else {
+					echo "ERROR: This IP ($id) already exists in the database and --proxy was not specified.\n";
+					exit(1);
+				}
+			} else {
+				$fail = true;
+			}
+		} else {
+			$fail = true;
+		}
+
+		if ($fail) {
+			db_execute("UPDATE host SET description = '$description' WHERE id = " . $addresses[$ip]);
+			echo "ERROR: This IP already exists in the database ($ip) device-id: (" . $addresses[$ip] . ")\n";
+			exit(1);
+		}
+	}
+
+	if (!is_numeric($site_id) || $site_id < 0) {
+		echo "ERROR: You have specified an invalid site id!\n";
+		exit(1);
+	}
+
+	if (!is_numeric($poller_id) || $poller_id < 0) {
+		echo "ERROR: You have specified an invalid poller id!\n";
 		exit(1);
 	}
 
@@ -290,7 +392,7 @@ if (sizeof($parms)) {
 	if ($snmp_ver < 0 || $snmp_ver > 3) {
 		echo "ERROR: Invalid snmp version ($snmp_ver)\n";
  		exit(1);
-	}elseif ($snmp_ver > 0) {
+	} elseif ($snmp_ver > 0) {
 		if ($snmp_port <= 1 || $snmp_port > 65534) {
 			echo "ERROR: Invalid port.  Valid values are from 1-65534\n";
 			exit(1);
@@ -305,7 +407,7 @@ if (sizeof($parms)) {
 	/* community/user/password verification */
 	if ($snmp_ver < 3) {
 		/* snmp community can be blank */
-	}else{
+	} else {
 		if ($snmp_username == "" || $snmp_password == "") {
 			echo "ERROR: When using snmpv3 you must supply an username and password\n";
 			exit(1);
@@ -320,18 +422,19 @@ if (sizeof($parms)) {
 
 	if ($disable == 0) {
 		$disable = "";
-	}else{
+	} else {
 		$disable = "on";
 	}
 
 	echo "Adding $description ($ip) as \"" . $host_templates[$template_id] . "\" using SNMP v$snmp_ver with community \"$community\"\n";
 
-	$host_id = api_device_save(0, $template_id, $description, $ip,
-				$community, $snmp_ver, $snmp_username, $snmp_password,
-				$snmp_port, $snmp_timeout, $disable, $avail, $ping_method,
-				$ping_port, $ping_timeout, $ping_retries, $notes,
-				$snmp_auth_protocol, $snmp_priv_passphrase,
-				$snmp_priv_protocol, $snmp_context, $max_oids, $device_threads);
+	$host_id = api_device_save('0', $template_id, $description, $ip,
+		$community, $snmp_ver, $snmp_username, $snmp_password,
+		$snmp_port, $snmp_timeout, $disable, $avail, $ping_method,
+		$ping_port, $ping_timeout, $ping_retries, $notes,
+		$snmp_auth_protocol, $snmp_priv_passphrase,
+		$snmp_priv_protocol, $snmp_context, $snmp_engine_id, $max_oids, $device_threads,
+		$poller_id, $site_id, $external_id);
 
 	if (is_error_message()) {
 		echo "ERROR: Failed to add this device\n";
@@ -340,31 +443,44 @@ if (sizeof($parms)) {
 		echo "Success - new device-id: ($host_id)\n";
 		exit(0);
 	}
-}else{
+} else {
 	display_help();
 	exit(0);
 }
 
+/*  display_version - displays version information */
+function display_version() {
+	$version = get_cacti_version();
+	echo "Cacti Add Device Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+}
+
 function display_help() {
-	echo "Add Device Script 1.0, Copyright 2004-2012 - The Cacti Group\n\n";
-	echo "A simple command line utility to add a device in Cacti\n\n";
-	echo "usage: add_device.php --description=[description] --ip=[IP] --template=[ID] [--notes=\"[]\"] [--disable]\n";
-	echo "    [--avail=[ping]] --ping_method=[icmp] --ping_port=[N/A, 1-65534] --ping_retries=[2]\n";
-	echo "    [--version=[1|2|3]] [--community=] [--port=161] [--timeout=500]\n";
-	echo "    [--username= --password=] [--authproto=] [--privpass= --privproto=] [--context=]\n";
+	display_version();
+
+	echo "\nusage: add_device.php --description=[description] --ip=[IP] --template=[ID] [--notes=\"[]\"] [--disable]\n";
+	echo "    [--poller=[id]] [--site=[id] [--external-id=[S]] [--proxy] [--threads=[1]\n";
+	echo "    [--avail=[ping]] --ping_method=[icmp] --ping_port=[N/A, 1-65534] --ping_timeout=[N] --ping_retries=[2]\n";
+	echo "    [--version=[0|1|2|3]] [--community=] [--port=161] [--timeout=500]\n";
+	echo "    [--username= --password=] [--authproto=] [--privpass= --privproto=] [--context=] [--engineid=]\n";
 	echo "    [--quiet]\n\n";
 	echo "Required:\n";
 	echo "    --description  the name that will be displayed by Cacti in the graphs\n";
-	echo "    --ip           self explanatory (can also be a FQDN)\n";
+	echo "    --ip           self explanatory (can also be a FQDN)\n\n";
 	echo "Optional:\n";
+	echo "    --proxy        if specified, allows adding a second host with same ip address\n";
 	echo "    --template     0, is a number (read below to get a list of templates)\n";
 	echo "    --notes        '', General information about this host.  Must be enclosed using double quotes.\n";
+	echo "    --external-id  '', An external ID to align Cacti devices with devices from other systems.\n";
 	echo "    --disable      0, 1 to add this host but to disable checks and 0 to enable it\n";
+	echo "    --poller       0, numeric poller id that will perform data collection for the device.\n";
+	echo "    --site         0, numeric site id that will be associated with the device.\n";
+	echo "    --threads      1, numeric number of threads to poll device with.\n";
 	echo "    --avail        pingsnmp, [ping][none, snmp, pingsnmp]\n";
 	echo "    --ping_method  tcp, icmp|tcp|udp\n";
 	echo "    --ping_port    '', 1-65534\n";
 	echo "    --ping_retries 2, the number of time to attempt to communicate with a host\n";
-	echo "    --version      1, 1|2|3, snmp version\n";
+	echo "    --ping_timeout N, the ping timeout in milliseconds.  Defaults to database setting.\n";
+	echo "    --version      1, 0|1|2|3, snmp version.  0 for no snmp\n";
 	echo "    --community    '', snmp community string for snmpv1 and snmpv2.  Leave blank for no community\n";
 	echo "    --port         161\n";
 	echo "    --timeout      500\n";
@@ -374,11 +490,10 @@ function display_help() {
 	echo "    --privpass     '', snmp privacy passphrase for snmpv3\n";
 	echo "    --privproto    '', snmp privacy protocol for snmpv3\n";
 	echo "    --context      '', snmp context for snmpv3\n";
+	echo "    --engineid     '', snmp engineid for snmpv3\n";
 	echo "    --max_oids     10, 1-60, the number of OID's that can be obtained in a single SNMP Get request\n\n";
 	echo "List Options:\n";
 	echo "    --list-host-templates\n";
 	echo "    --list-communities\n";
 	echo "    --quiet - batch mode value return\n\n";
 }
-
-?>
