@@ -39,9 +39,9 @@ $parms = $_SERVER['argv'];
 array_shift($parms);
 
 if (sizeof($parms)) {
-	$displayHosts 			= FALSE;
-	$displayGraphTemplates 	= FALSE;
-	$quietMode				= FALSE;
+	$displayHosts 			= false;
+	$displayGraphTemplates 	= false;
+	$quietMode				= false;
 	unset($host_id);
 	unset($graph_template_id);
 
@@ -55,7 +55,7 @@ if (sizeof($parms)) {
 
 		switch ($arg) {
 		case '-d':
-			$debug = TRUE;
+			$debug = true;
 
 			break;
 		case '--host-id':
@@ -85,13 +85,13 @@ if (sizeof($parms)) {
 			display_help();
 			exit(0);
 		case '--list-hosts':
-			$displayHosts = TRUE;
+			$displayHosts = true;
 			break;
 		case '--list-graph-templates':
-			$displayGraphTemplates = TRUE;
+			$displayGraphTemplates = true;
 			break;
 		case '--quiet':
-			$quietMode = TRUE;
+			$quietMode = true;
 			break;
 		default:
 			echo "ERROR: Invalid Argument: ($arg)\n\n";
@@ -151,7 +151,7 @@ if (sizeof($parms)) {
 		($exists_already > 0)) {
 		echo "ERROR: Graph Template is already associated for host: ($host_id: $host_name) - graph-template: ($graph_template_id: $graph_template_name)\n";
 		exit(1);
-	}else{
+	} else {
 		db_execute("replace into host_graph (host_id,graph_template_id) values (" . $host_id . "," . $graph_template_id . ")");
 
 		automation_hook_graph_template($host_id, $graph_template_id);
@@ -166,14 +166,14 @@ if (sizeof($parms)) {
 		echo "Success: Graph Template associated for host: ($host_id: $host_name) - graph-template: ($graph_template_id: $graph_template_name)\n";
 		exit(0);
 	}
-}else{
+} else {
 	display_help();
 	exit(0);
 }
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = db_fetch_cell('SELECT cacti FROM version');
+	$version = get_cacti_version();
 	echo "Cacti Add Graph Template Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
