@@ -47,16 +47,16 @@ if (file_exists('../include/global.php')) {
 ini_set('memory_limit', '-1');
 
 /* setup defaults */
-$debug     = FALSE;
-$dryrun    = FALSE;
+$debug     = false;
+$dryrun    = false;
 $out_start = '';
 $out_end   = '';
 $rrdfile   = '';
-$std_kills = FALSE;
-$var_kills = FALSE;
-$html      = FALSE;
-$backup    = FALSE;
-$out_set   = FALSE;
+$std_kills = false;
+$var_kills = false;
+$html      = false;
+$backup    = false;
+$out_set   = false;
 $username  = 'OsUser:' . get_current_user();
 
 if ($using_cacti) {
@@ -220,7 +220,7 @@ if (sizeof($parms)) {
 					exit(-6);
 				}
 
-				$out_set = TRUE;
+				$out_set = true;
 
 				break;
 			case '--percent':
@@ -235,21 +235,21 @@ if (sizeof($parms)) {
 
 				break;
 			case '--html':
-				$html = TRUE;
+				$html = true;
 
 				break;
 			case '--backup':
-				$backup = TRUE;
+				$backup = true;
 
 				break;
 			case '-d':
 			case '--debug':
-				$debug = TRUE;
+				$debug = true;
 
 				break;
 			case '-D':
 			case '--dryrun':
-				$dryrun = TRUE;
+				$dryrun = true;
 
 				break;
 			case '--number':
@@ -316,9 +316,9 @@ if (!isset($stddev)) {
 
 if (!isset($percent)) {
 	if (!isset($upercent)) {
-		$percent = $dpercent;
+		$percent = $dpercent/100;
 	} else {
-		$percent = $upercent;
+		$percent = $upercent/100;
 	}
 }
 
