@@ -141,6 +141,7 @@ case 'save':
 		get_filter_request_var('predefined_timeshift');
 		get_filter_request_var('graphs');
 		get_filter_request_var('graph_template_id', FILTER_VALIDATE_IS_NUMERIC_LIST);
+		get_filter_request_var('thumbnails', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => '(true|false)')));
 
 		if (isset_request_var('predefined_timespan')) {
 			set_graph_config_option('default_timespan', get_request_var('predefined_timespan'));
@@ -703,7 +704,7 @@ case 'list':
 		$('#form_graph_list').find('select, input').each(function() {
 			switch($(this).attr('id')) {
 			case 'graph_template_id':
-				strURL += '&' + $(this).attr('id') + '=' + $(this).prop('selectedIndex');
+				strURL += '&' + $(this).attr('id') + '=' + $(this).val();
 				break;
 			case 'host_id':
 			case 'rfilter':
@@ -719,9 +720,13 @@ case 'list':
 			}
 		});
 
-		strURL += '&reset=1';
+		strURL += '&reset=1&header=false';
 
-		document.location = strURL;
+		loadPageNoHeader(strURL);
+
+		$('#breadcrumbs').empty().html('<li><a href="graph_view.php?action=preview"><?php print __('Preview Mode');?></a></li>');
+		$('#listview').removeClass('selected');
+		$('#preview').addClass('selected');
 	}
 
 	function url_graph(strNavURL) {
