@@ -30,7 +30,7 @@ api_plugin_hook('console_before');
 function render_external_links($style = 'FRONT') {
 	global $config;
 
-	$consoles = db_fetch_assoc_prepared('SELECT * FROM external_links WHERE style = ?', array($style));
+	$consoles = db_fetch_assoc_prepared('SELECT id, contentfile FROM external_links WHERE style = ?', array($style));
 	if (sizeof($consoles)) {
 		foreach($consoles as $page) {
 			if (is_realm_allowed($page['id']+10000)) {
@@ -70,7 +70,7 @@ if (read_config_option('hide_console') != '1') {
 			</ul>
 		</td>
 		<td class="textAreaNotes top right">
-			<strong><?php print __('Version %s', $config['cacti_version']);?></strong>
+			<strong><?php print __('Version %s', CACTI_VERSION);?></strong>
 		</td>
 	</tr>
 	<?php if ($config['poller_id'] > 1) {?>
@@ -82,14 +82,14 @@ if (read_config_option('hide_console') != '1') {
 	<tr><td><hr></td></tr>
 	<tr>
 		<td class="textAreaNotes top left">
-			<?php print __('<strong>NOTE:</strong> You are logged into a Remote Data Collector.  When <b>\'online\'</b>, you will be able to view and control much of the Main Cacti Web Site just as if you were logged into it.  Also, it\'s important to note that Remote Data Collectors are required to use the Cacti\'s Performance Boosting Services <b>\'On Demand Updating\'</b> feature, and we always recommend using Spine.  When the Remote Data Collector is <b>\'offline\'</b>, the Remote Data Collectos Web Site will contain much less information.  However, it will cache all updates until the Main Cacti Database and Web Server are reachable.  Then it will dump it\'s Boost table output back to the Main Cacti Database for updating.');?>
+			<?php print __('<strong>NOTE:</strong> You are logged into a Remote Data Collector.  When <b>\'online\'</b>, you will be able to view and control much of the Main Cacti Web Site just as if you were logged into it.  Also, it\'s important to note that Remote Data Collectors are required to use the Cacti\'s Performance Boosting Services <b>\'On Demand Updating\'</b> feature, and we always recommend using Spine.  When the Remote Data Collector is <b>\'offline\'</b>, the Remote Data Collectors Web Site will contain much less information.  However, it will cache all updates until the Main Cacti Database and Web Server are reachable.  Then it will dump it\'s Boost table output back to the Main Cacti Database for updating.');?>
 		</td>
-	</td>
+	</tr>
 	<tr>
 		<td class="textAreaNotes top left">
 			<?php print __('<strong>NOTE:</strong> None of the Core Cacti Plugins, to date, have been re-designed to work with Remote Data Collectors.  Therefore, Plugins such as MacTrack, and HMIB, which require direct access to devices will not work with Remote Data Collectors at this time.  However, plugins such as Thold will work so long as the Remote Data Collector is in <b>\'online\'</b> mode.');?>
 		</td>
-	</td>
+	</tr>
 	<?php } ?>
 </table>
 
