@@ -145,8 +145,6 @@ function api_device_dq_change($device_id, $data_query_id, $reindex_method) {
 		ON DUPLICATE KEY UPDATE reindex_method=VALUES(reindex_method)',
 		array($device_id, $data_query_id, $reindex_method));
 
-	cacti_log("INSERT INTO host_snmp_query (host_id, snmp_query_id, reindex_method) VALUES ($device_id, $data_query_id, $reindex_method) ON DUPLICATE KEY UPDATE reindex_method=VALUES(reindex_method)");
-
 	db_execute_prepared('DELETE FROM poller_reindex
 		WHERE data_query_id = ?
 		AND host_id = ?', array($data_query_id, $device_id));
@@ -290,14 +288,14 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 								(chgrp($host_dir, $group_id))) {
 								/* permissions set ok */
 							} else {
-								cacti_log("ERROR: Unable to set directory permissions for '" . $host_dir . "'", FALSE);
+								cacti_log("ERROR: Unable to set directory permissions for '" . $host_dir . "'", false);
 							}
 						}
 					} else {
-						cacti_log("ERROR: Unable to create directory '" . $host_dir . "'", FALSE);
+						cacti_log("ERROR: Unable to create directory '" . $host_dir . "'", false);
 					}
 				} else {
-					cacti_log("ERROR: Unable to create directory due to missing write permissions '" . $host_dir . "'", FALSE);
+					cacti_log("ERROR: Unable to create directory due to missing write permissions '" . $host_dir . "'", false);
 				}
 			}
 		}
