@@ -845,6 +845,9 @@ function reports_item_edit() {
 		}else if (!isset($reports_item['tree_id'])) {
 			$reports_item['tree_id'] = 0;
 		}
+	} else {
+		$fields_reports_item_edit['branch_id']['sql'] =
+			"SELECT '0' AS id, '" . __('None') . "' AS name";
 	}
 
 	if (isset_request_var('host_template_id')) {
@@ -1447,7 +1450,7 @@ function reports() {
 		</td>
 	</tr>\n";
 
-	html_end_box(TRUE);
+	html_end_box(true);
 
 	form_end();
 
@@ -1549,10 +1552,10 @@ function reports() {
 				}
 			}
 
-			$interval = 'Every ' . $report['count'] . ' ' . $reports_interval[$report['intrvl']];
+			$interval = __('Every') . ' ' . $report['count'] . ' ' . $reports_interval[$report['intrvl']];
 
 			form_selectable_cell($interval, $report['id']);
-			form_selectable_cell(($report['lastsent'] == 0) ? 'Never' : date($date_format, $report['lastsent']), $report['lastsent']);
+			form_selectable_cell(($report['lastsent'] == 0) ? __('Never') : date($date_format, $report['lastsent']), $report['lastsent']);
 			form_selectable_cell(date($date_format, $report['mailtime']), $report['id']);
 			form_selectable_cell($report['from_name'], $report['id']);
 			form_selectable_cell((substr_count($report['email'], ',') ? __('Multiple'): $report['email']), $report['id']);
