@@ -155,7 +155,7 @@ function form_alternate_row($row_id = '', $light = false, $disabled = false) {
    @arg $width - the width of the table element
    @arg $style_or_class - the style or class to apply to the table element
    @arg $title - optional title for the column */
-function form_selectable_cell($contents, $id, $width='', $style_or_class = '', $title = '') {
+function form_selectable_cell($contents, $id, $width = '', $style_or_class = '', $title = '') {
 	$output = '';
 
 	if ($style_or_class != '') {
@@ -165,9 +165,9 @@ function form_selectable_cell($contents, $id, $width='', $style_or_class = '', $
 				$output .= " style='width:$width;'";
 			}
 		} else {
-			$output = "style='nowrap " . $style_or_class;
+			$output = "class='nowrap' style='" . $style_or_class;
 			if ($width != '') {
-				$output .= ($output != '' ? ';':'') . "width:$width;";
+				$output .= ";width:$width;";
 			}
 			$output .= "'";
 		}
@@ -383,7 +383,7 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 				if ($valid === true) {
 					$value = $_REQUEST[$name];
 				} else {
-					$value = FALSE;
+					$value = false;
 					$custom_error = $valid;
 				}
 			} elseif ($filter == FILTER_VALIDATE_IS_NUMERIC_ARRAY) {
@@ -428,7 +428,7 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 
 		if ($value === false) {
 			if ($filter == FILTER_VALIDATE_IS_REGEX) {
-				$_SESSION['custom_error'] = __('The search term "%s" is not valid. Error is %s', get_nfilter_request_var($name), $cusom_error);
+				$_SESSION['custom_error'] = __('The search term "%s" is not valid. Error is %s', get_nfilter_request_var($name), $custom_error);
 				set_request_var($name, '');
 				raise_message('custom_error');
 			} else {
