@@ -140,7 +140,8 @@ function update_poller_cache($data_source, $commit = false) {
 		FROM data_template_data AS dtd
 		INNER JOIN data_input AS di
 		ON dtd.data_input_id=di.id
-		WHERE dtd.local_data_id = ?', array($data_source['id']));
+		WHERE dtd.local_data_id = ?',
+		array($data_source['id']));
 
 	if (sizeof($data_input)) {
 		/* we have to perform some additional sql queries if this is a 'query' */
@@ -409,7 +410,14 @@ function update_poller_cache($data_source, $commit = false) {
 			}
 		}
 	} else {
-		cacti_log('WARNING: Repopulate Poller Cache found Data Input Missing for Data Source ' . $data_source['id'] . '.  Database may be corrupted');
+		$data_template_data = db_fetch_row_prepared('SELECT ' . SQL_NO_CACHE . ' *
+			FROM data_template_data
+			WHERE local_data_id = ?',
+			array($data_source['id']));
+
+		if (sizeof($data_template_data) && $data_template_data['data_input_id'] > 0) {
+			cacti_log('WARNING: Repopulate Poller Cache found Data Input Missing for Data Source ' . $data_source['id'] . '.  Database may be corrupted');
+		}
 	}
 
 	if ($commit && sizeof($poller_items)) {
@@ -675,7 +683,7 @@ function utilities_get_mysql_recommendations() {
 		'version' => array(
 			'value' => '5.6',
 			'measure' => 'gt',
-			'comment' => __('MySQL 5.6+ and MariaDB 10.0+ are great releases, and are very good versions to choose. Make sure you run the very latest release though which fixes a long standing low level networking issue that was casuing spine many issues with reliability.')
+			'comment' => __('MySQL 5.6+ and MariaDB 10.0+ are great releases, and are very good versions to choose. Make sure you run the very latest release though which fixes a long standing low level networking issue that was causing spine many issues with reliability.')
 			)
 	);
 
@@ -706,7 +714,7 @@ function utilities_get_mysql_recommendations() {
 				'value' => 'utf8',
 				'class' => 'warning',
 				'measure' => 'equal',
-				'comment' => __('When using Cacti with languages other than English, it is important ot use the utf8 character set as some characters take more than a single byte.  If you are first just now installing Cacti, stop, make the changes and start over again.  If your Cacti has been running and is in production, see the internet for instructions on converting your databases and tables if you plan on supporting other languages.')
+				'comment' => __('When using Cacti with languages other than English, it is important to use the utf8 character set as some characters take more than a single byte. If you are first just now installing Cacti, stop, make the changes and start over again. If your Cacti has been running and is in production, see the internet for instructions on converting your databases and tables if you plan on supporting other languages.')
 				)
 		);
 	} else {
