@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2012 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -48,7 +48,7 @@ function get_children($vals, &$i) {
 		if ($vals[$i]['value']) array_push($children, $vals[$i]['value']);
 	}
 
-	$prevtag = ""; $j = 0;
+	$prevtag = ''; $j = 0;
 
 	while (++$i < count($vals)) {
 		switch ($vals[$i]['type']) {
@@ -60,8 +60,8 @@ function get_children($vals, &$i) {
 			in its array, so we need to check for this first */
 			if (isset($vals[$i]['value'])) {
 				$children{($vals[$i]['tag'])} = $vals[$i]['value'];
-			}else{
-				$children{($vals[$i]['tag'])} = "";
+			} else {
+				$children{($vals[$i]['tag'])} = '';
 			}
 
 			break;
@@ -82,17 +82,20 @@ function get_children($vals, &$i) {
 }
 
 function rrdxport2array($data) {
+	// Bug force encoding to UTF-8
+	$data = str_replace(array('US-ASCII', 'ISO-8859-1'), 'UTF-8', $data);
+
 	/* bug #1436 */
 	/* scan XML for bad data RRDtool 1.2.30 */
 	$array = explode("\n", $data);
 
 	if (sizeof($array)){
-		if ((substr(trim($array[0]),0,1)) == "<") {
+		if ((substr(trim($array[0]),0,1)) == '<') {
 			/* continue */
-		}else{
+		} else {
 			$new_array = array();
 			foreach($array as $element) {
-				if ((substr(trim($element),0,1)) == "<") {
+				if ((substr(trim($element),0,1)) == '<') {
 					$new_array[] = $element;
 				}
 			}
@@ -106,11 +109,12 @@ function rrdxport2array($data) {
 	/* mvo voncken@mailandnews.com
 	original ripped from  on the php-manual:gdemartini@bol.com.br
 	to be used for data retrieval(result-structure is Data oriented) */
-	$p = xml_parser_create();
+	$p = xml_parser_create('UTF-8');
 	$vals = array();
 	$index = array();
 	xml_parser_set_option($p, XML_OPTION_SKIP_WHITE, 1);
 	xml_parser_set_option($p, XML_OPTION_CASE_FOLDING, 0);
+	xml_parser_set_option($p, XML_OPTION_TARGET_ENCODING, 'UTF-8');
 	xml_parse_into_struct($p, $data, $vals, $index);
 	xml_parser_free($p);
 
@@ -130,7 +134,7 @@ function get_rrd_children($vals, &$i, &$column, &$row) {
 		if ($vals[$i]['value']) array_push($children, $vals[$i]['value']);
 	}
 
-	$prevtag = ""; $j = 0;
+	$prevtag = ''; $j = 0;
 
 	while (++$i < count($vals)) {
 		switch ($vals[$i]['type']) {
@@ -142,22 +146,22 @@ function get_rrd_children($vals, &$i, &$column, &$row) {
 			in its array, so we need to check for this first */
 			if (isset($vals[$i]['value'])) {
 				switch($vals[$i]['tag']) {
-					case "entry":
+					case 'entry':
 						$column++;
-						$children["col" . $column] = $vals[$i]['value'];
+						$children['col' . $column] = $vals[$i]['value'];
 						break;
-					case "t":
-						$children["timestamp"] = $vals[$i]['value'];
+					case 't':
+						$children['timestamp'] = $vals[$i]['value'];
 						break;
-					case "v":
+					case 'v':
 						$column++;
-						$children["col" . $column] = $vals[$i]['value'];
+						$children['col' . $column] = $vals[$i]['value'];
 						break;
 					default:
 						$children{($vals[$i]['tag'])} = $vals[$i]['value'];
 				}
-			}else{
-				$children{($vals[$i]['tag'])} = "";
+			} else {
+				$children{($vals[$i]['tag'])} = '';
 			}
 
 			break;
@@ -170,17 +174,17 @@ function get_rrd_children($vals, &$i, &$column, &$row) {
 			}
 
 			switch($vals[$i]['tag']) {
-				case "meta":
-				case "xport":
-				case "legend":
+				case 'meta':
+				case 'xport':
+				case 'legend':
 					$children{($vals[$i]['tag'])} = get_rrd_children($vals,$i,$column,$row);
 					break;
-				case "data":
+				case 'data':
 					break;
-				case "row":
+				case 'row':
 					$row++;
 					$column=0;
-					$children["data"][$row] = get_rrd_children($vals,$i,$column,$row);
+					$children['data'][$row] = get_rrd_children($vals,$i,$column,$row);
 
 					break;
 			}
@@ -192,4 +196,3 @@ function get_rrd_children($vals, &$i, &$column, &$row) {
 	}
 }
 
-?>
