@@ -107,11 +107,9 @@ switch (get_request_var('action')) {
 		break;
 	case 'ajax_hosts':
 		get_allowed_ajax_hosts();
-
 		break;
 	case 'ajax_hosts_noany':
 		get_allowed_ajax_hosts(false);
-
 		break;
 	default:
 		if (!api_plugin_hook_function('utilities_action', get_request_var('action'))) {
@@ -132,7 +130,7 @@ function rebuild_resource_cache() {
 
 	raise_message('resource_cache_rebuild');
 
-	cacti_log('NOTE: Poller Resource Cache scheduled for rebuild by user ' . get_username($_SESSION['sess_user_id']), false, 'WEBUI');
+    cacti_log('NOTE: Poller Resource Cache scheduled for rebuild by user ' . get_username($_SESSION['sess_user_id']), false, 'WEBUI');
 }
 
 function utilities_view_tech($php_info = '') {
@@ -900,28 +898,26 @@ function utilities_view_logfile() {
 			'default' => '1'
 			),
 		'tail_lines' => array(
-			'filter' => FILTER_VALIDATE_INT,
+			'filter'  => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'rfilter' => array(
-			'filter' => FILTER_VALIDATE_IS_REGEX,
+			'filter'  => FILTER_VALIDATE_IS_REGEX,
 			'pageset' => true,
 			'default' => ''
 			),
 		'message_type' => array(
-			'filter' => FILTER_VALIDATE_INT,
+			'filter'  => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'reverse' => array(
-			'filter' => FILTER_VALIDATE_INT,
-			'pageset' => true,
+			'filter'  => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'refresh' => array(
-			'filter' => FILTER_VALIDATE_INT,
-			'pageset' => true,
+			'filter'  => FILTER_VALIDATE_INT,
 			'default' => read_config_option('log_refresh_interval')
 			)
 	);
@@ -1911,17 +1907,17 @@ function boost_display_run_status() {
 
 	load_current_session_value('refresh', 'sess_boost_utilities_refresh', '30');
 
-	$last_run_time   = read_config_option('boost_last_run_time', TRUE);
-	$next_run_time   = read_config_option('boost_next_run_time', TRUE);
+	$last_run_time   = read_config_option('boost_last_run_time', true);
+	$next_run_time   = read_config_option('boost_next_run_time', true);
 
-	$rrd_updates     = read_config_option('boost_rrd_update_enable', TRUE);
-	$boost_cache     = read_config_option('boost_png_cache_enable', TRUE);
+	$rrd_updates     = read_config_option('boost_rrd_update_enable', true);
+	$boost_cache     = read_config_option('boost_png_cache_enable', true);
 
-	$max_records     = read_config_option('boost_rrd_update_max_records', TRUE);
-	$max_runtime     = read_config_option('boost_rrd_update_max_runtime', TRUE);
-	$update_interval = read_config_option('boost_rrd_update_interval', TRUE);
-	$peak_memory     = read_config_option('boost_peak_memory', TRUE);
-	$detail_stats    = read_config_option('stats_detail_boost', TRUE);
+	$max_records     = read_config_option('boost_rrd_update_max_records', true);
+	$max_runtime     = read_config_option('boost_rrd_update_max_runtime', true);
+	$update_interval = read_config_option('boost_rrd_update_interval', true);
+	$peak_memory     = read_config_option('boost_peak_memory', true);
+	$detail_stats    = read_config_option('stats_detail_boost', true);
 
 	$refresh['seconds'] = get_request_var('refresh');
 	$refresh['page']    = 'utilities.php?action=view_boost_status&header=false';
@@ -1997,7 +1993,7 @@ function boost_display_run_status() {
 
 	$total_data_sources = db_fetch_cell('SELECT COUNT(*) FROM poller_item');
 
-	$boost_status = read_config_option('boost_poller_status', TRUE);
+	$boost_status = read_config_option('boost_poller_status', true);
 	if ($boost_status != '') {
 		$boost_status_array = explode(':', $boost_status);
 
@@ -2013,7 +2009,7 @@ function boost_display_run_status() {
 		$boost_status_date = '';
 	}
 
-	$stats_boost = read_config_option('stats_boost', TRUE);
+	$stats_boost = read_config_option('stats_boost', true);
 	if ($stats_boost != '') {
 		$stats_boost_array = explode(' ', $stats_boost);
 
@@ -2028,13 +2024,13 @@ function boost_display_run_status() {
 	}
 
 	/* get cache directory size/contents */
-	$cache_directory    = read_config_option('boost_png_cache_directory', TRUE);
+	$cache_directory    = read_config_option('boost_png_cache_directory', true);
 	$directory_contents = array();
 
 	if (is_dir($cache_directory)) {
 		if ($handle = @opendir($cache_directory)) {
 			/* This is the correct way to loop over the directory. */
-			while (FALSE !== ($file = readdir($handle))) {
+			while (false !== ($file = readdir($handle))) {
 				$directory_contents[] = $file;
 			}
 
@@ -2112,12 +2108,12 @@ function boost_display_run_status() {
 	if ($output_length != '') {
 		$parts = explode(':', $output_length);
 		if ((time()-1200) > $parts[0]) {
-			$ref = TRUE;
+			$ref = true;
 		} else {
-			$ref = FALSE;
+			$ref = false;
 		}
 	} else {
-		$ref = TRUE;
+		$ref = true;
 	}
 
 	if ($ref) {
@@ -2210,7 +2206,7 @@ function boost_display_run_status() {
 	form_alternate_row();
 	print '<td>' . __('Cached Files Size:') . '</td><td>' . $directory_size . '</td>';
 
-	html_end_box(TRUE);
+	html_end_box(true);
 }
 
 /**
